clear all
global rootdir "D:\Academics\Current\Courses\2014.11.24 - Stata Programming\NIDS2008"
global subdir "$rootdir\Subfiles"
cap mkdir "$subdir"

* 1. Consider the following three files (notice the pattern?)
import delimited "$rootdir\Eastern Cape\NIDS Wave I 2008 for African Female.csv", clear
import delimited "$rootdir\Eastern Cape\NIDS Wave I 2008 for African Male.csv", clear
import delimited "$rootdir\Eastern Cape\NIDS Wave I 2008 for African No Info Gender.csv", clear

foreach gender in "Female" "Male" "No Info Gender" {
	import delimited "$rootdir\Eastern Cape\NIDS Wave I 2008 for African `gender'.csv", clear
}	

* 2. But why stop there?  The pattern is broader than just gender...

* Consider the following three files (notice the pattern?)
import delimited "$rootdir\Eastern Cape\NIDS Wave I 2008 for African Female.csv", clear
import delimited "$rootdir\Eastern Cape\NIDS Wave I 2008 for African Male.csv", clear
import delimited "$rootdir\Eastern Cape\NIDS Wave I 2008 for African No Info Gender.csv", clear
import delimited "$rootdir\Eastern Cape\NIDS Wave I 2008 for Coloured Female.csv", clear
import delimited "$rootdir\Eastern Cape\NIDS Wave I 2008 for Coloured Male.csv", clear
import delimited "$rootdir\Eastern Cape\NIDS Wave I 2008 for Coloured No Info Gender.csv", clear
*............................
import delimited "$rootdir\Eastern Cape\NIDS Wave I 2008 for No Info Race Male.csv", clear
import delimited "$rootdir\Eastern Cape\NIDS Wave I 2008 for No Info Race No Info Gender.csv", clear

foreach race in "African" "Coloured" "Asian_Indian" "White" "No Info Race" {
	foreach gender in "Female" "Male" "No Info Gender" {
		import delimited "$rootdir\Eastern Cape\NIDS Wave I 2008 for `race' `gender'.csv", clear
	}	
}	


* 3. But why stop there??  The pattern is broader than just race and gender...
import delimited "$rootdir\Eastern Cape\NIDS Wave I 2008 for African Female.csv", clear
import delimited "$rootdir\Eastern Cape\NIDS Wave I 2008 for African Male.csv", clear
*............................
import delimited "$rootdir\Free State\NIDS Wave I 2008 for African Female.csv", clear
import delimited "$rootdir\Free State\NIDS Wave I 2008 for African Male.csv", clear

*............................
import delimited "$rootdir\Western Cape\NIDS Wave I 2008 for African Female.csv", clear
import delimited "$rootdir\Western Cape\NIDS Wave I 2008 for African.csv", clear

foreach province in "Eastern Cape" "Free State" "Gauteng" "Kwazulu-Natal" "Limpopo" "Mpumalanga" "No Info Province" "North West" "Northern Cape" "Western Cape" {
	foreach race in "African" "Coloured" "Asian_Indian" "White" "No Info Race" {
		foreach gender in "Female" "Male" "No Info Gender" {
			import delimited "$rootdir\\`province'\\NIDS Wave I 2008 for `race' `gender'.csv", clear
		}	
	}
}	

* 4. The loop works, so now to include the commands 
foreach province in "Eastern Cape" "Free State" "Gauteng" "Kwazulu-Natal" "Limpopo" "Mpumalanga" "No Info Province" "North West" "Northern Cape" "Western Cape" {
	foreach race in "African" "Coloured" "Asian_Indian" "White" "No Info Race" {
		foreach gender in "Female" "Male" "No Info Gender" {
			import delimited "$rootdir\\`province'\\NIDS Wave I 2008 for `race' `gender'.csv", clear
			gen province = "`province"
			gen race = "`race'"
			gen gender = "`gender'"
			save "$subdir\\`province' NIDS Wave I 2008 for `race' `gender'.dta", replace
		}	
	}
}	


* How do you append all of the subfiles for the dataset?
clear
append using "$subdir\Eastern Cape NIDS Wave I 2008 for African Female.dta"
append using "$subdir\Eastern Cape NIDS Wave I 2008 for African Male"
*............................
append using "$subdir\Western Cape NIDS Wave I 2008 for White Male.dta"
append using "$subdir\Western Cape NIDS Wave I 2008 for White No Info Gender.dta"
* And do this for all 150 files...

* 5. But all of the subfiles are in the same directory, and they all have the same extension
* 	This means we can use a neat stata trick

cd "$subdir"
local files "`: dir . files "*.dta'"
foreach file in `files' {
	di "`file'"
}	

* 6. Using this trick to append the files
cd "$subdir"
local files "`: dir . files "*.dta'"
clear
foreach file in `files' {
	append using "`file'", force
}	
save NIDS2008_compiled.dta


* 7. Putting it all together
* Create the stata subfiles
foreach province in "Eastern Cape" "Free State" "Gauteng" "Kwazulu-Natal" "Limpopo" "Mpumalanga" "No Info Province" "North West" "Northern Cape" "Western Cape" {
	foreach race in "African" "Coloured" "Asian_Indian" "White" "No Info Race" {
		foreach gender in "Female" "Male" "No Info Gender" {
			import delimited "$rootdir\\`province'\\NIDS Wave I 2008 for `race' `gender'.csv", clear
			gen province = "`province'"
			gen race = "`race'"
			gen gender = "`gender'"
			save "$subdir\\`province' NIDS Wave I 2008 for `race' `gender'.dta", replace
		}	
	}
}	

* Append the subfiles
cd "$subdir"
local files "`: dir . files "*.dta'"
clear
foreach file in `files' {
	append using "`file'", force
	erase "`file'"
}	
save NIDS2008_compiled.dta, replace

